Index: wp-admin/includes/schema.php
===================================================================
--- wp-admin/includes/schema.php	(revision 31385)
+++ wp-admin/includes/schema.php	(working copy)
@@ -917,7 +917,7 @@
 		$site_admins = get_site_option( 'site_admins' );
 	}
 
-	$welcome_email = __( 'Dear User,
+	$welcome_email = __( 'Howdy USERNAME,
 
 Your new SITE_NAME site has been successfully set up at:
 BLOG_URL
Index: wp-admin/ms-delete-site.php
===================================================================
--- wp-admin/ms-delete-site.php	(revision 31385)
+++ wp-admin/ms-delete-site.php	(working copy)
@@ -26,6 +26,7 @@
 }
 
 $blog = get_blog_details();
+$user = wp_get_current_user();
 
 $title = __( 'Delete Site' );
 $parent_file = 'tools.php';
@@ -42,9 +43,11 @@
 
 	$url_delete = esc_url( admin_url( 'ms-delete-site.php?h=' . $hash ) );
 
-	$content = __( "Dear User,
+	$content = __( "Howdy ###USERNAME###,
+	
 You recently clicked the 'Delete Site' link on your site and filled in a
 form on that page.
+
 If you really want to delete your site, click the link below. You will not
 be asked to confirm again so only click this link if you are absolutely certain:
 ###URL_DELETE###
@@ -55,6 +58,7 @@
 
 Thanks for using the site,
 Webmaster
+
 ###SITE_NAME###" );
 	/**
 	 * Filter the email content sent when a site in a Multisite network is deleted.
@@ -67,6 +71,7 @@
 
 	$content = str_replace( '###URL_DELETE###', $url_delete, $content );
 	$content = str_replace( '###SITE_NAME###', $current_site->site_name, $content );
+	$content = str_replace( '###USERNAME###', $user->user_login, $content );
 
 	wp_mail( get_option( 'admin_email' ), "[ " . wp_specialchars_decode( get_option( 'blogname' ) ) . " ] ".__( 'Delete My Site' ), $content );
 	?>
Index: wp-includes/ms-functions.php
===================================================================
--- wp-includes/ms-functions.php	(revision 31385)
+++ wp-includes/ms-functions.php	(working copy)
@@ -1434,7 +1434,7 @@
 
 	$welcome_email = get_site_option( 'welcome_email' );
 	if ( $welcome_email == false )
-		$welcome_email = __( 'Dear User,
+		$welcome_email = __( 'Howdy USERNAME,
 
 Your new SITE_NAME site has been successfully set up at:
 BLOG_URL
@@ -2080,7 +2080,7 @@
 function welcome_user_msg_filter( $text ) {
 	if ( !$text ) {
 		remove_filter( 'site_option_welcome_user_email', 'welcome_user_msg_filter' );
-		$text = __( 'Dear User,
+		$text = __( 'Howdy USERNAME,
 
 Your new account is set up.
 

Index: wp-admin/includes/ms.php
===================================================================
--- wp-admin/includes/ms.php	(revision 31385)
+++ wp-admin/includes/ms.php	(working copy)
@@ -253,10 +253,11 @@
 	);
 	update_option( 'adminhash', $new_admin_email );
 
-	$email_text = __( 'Dear user,
+	$email_text = __( 'Howdy ###USERNAME###,
 
 You recently requested to have the administration email address on
 your site changed.
+
 If this is correct, please click on the following link to change it:
 ###ADMIN_URL###
 
@@ -277,6 +278,7 @@
 	 * ###EMAIL###     The new email.
 	 * ###SITENAME###  The name of the site.
 	 * ###SITEURL###   The URL to the site.
+	 * ###USERNAME###  The current user's username.
 	 *
 	 * @since MU
 	 *
@@ -289,6 +291,7 @@
 	$content = str_replace( '###EMAIL###', $value, $content );
 	$content = str_replace( '###SITENAME###', get_site_option( 'site_name' ), $content );
 	$content = str_replace( '###SITEURL###', network_home_url(), $content );
+	$content = str_replace( '###USERNAME###', $current_user->user_login, $content );
 
 	wp_mail( $value, sprintf( __( '[%s] New Admin Email Address' ), wp_specialchars_decode( get_option( 'blogname' ) ) ), $content );
 }
@@ -331,7 +334,7 @@
 				);
 		update_option( $current_user->ID . '_new_email', $new_user_email );
 
-		$email_text = __( 'Dear user,
+		$email_text = __( 'Howdy ###USERNAME###,
 
 You recently requested to have the email address on your account changed.
 If this is correct, please click on the following link to change it:
@@ -351,9 +354,10 @@
 		 *
 		 * The following strings have a special meaning and will get replaced dynamically:
 		 * ###ADMIN_URL### The link to click on to confirm the email change. Required otherwise this functunalty is will break.
 		 * ###EMAIL### The new email.
 		 * ###SITENAME### The name of the site.
 		 * ###SITEURL### The URL to the site.
 		 *
 		 * @since MU
 		 *
@@ -366,6 +370,7 @@
 		$content = str_replace( '###EMAIL###', $_POST['email'], $content);
 		$content = str_replace( '###SITENAME###', get_site_option( 'site_name' ), $content );
 		$content = str_replace( '###SITEURL###', network_home_url(), $content );
+		$content = str_replace( '###USERNAME###', $current_user->user_login, $content );
 
 		wp_mail( $_POST['email'], sprintf( __( '[%s] New Email Address' ), wp_specialchars_decode( get_option( 'blogname' ) ) ), $content );
 		$_POST['email'] = $current_user->user_email;
@@ -351,9 +354,10 @@
 		 * The following strings have a special meaning and will get replaced dynamically:
 		 * ###ADMIN_URL### The link to click on to confirm the email change. Required otherwise this functunalty is will break.
-		 * ###EMAIL### The new email.
-		 * ###SITENAME### The name of the site.
-		 * ###SITEURL### The URL to the site.
+		 * ###EMAIL###     The new email.
+		 * ###SITENAME###  The name of the site.
+		 * ###SITEURL###   The URL to the site.
+		 * ###USERNAME###  The current user's username. 
 		 *
 		 * @since MU